==> 1.0.4.tar.gz: lib/src/models/tropa.dart <==
import 'package:firebase_repository/src/entities/entities.dart';
import 'package:meta/meta.dart';

@immutable
class Tropa {
  ///Atributos obligatorios:
  final String uuid;
  final String nombre;
  final String categoriaUid;
  final String corralUid;
  final bool activo;
  final bool cerrado;
  final bool pendiente;
  final String potreroUid;
  final String propietario;
  final String dieta;
  final bool caravana;

  ///Atributos autogenerados
  final int cabezas;
  final DateTime fechaAlta;
  final DateTime fechaInicio;
  final DateTime fechaUltimoEncierre;
  final double metaKilos;
  final double pesoInicio;
  final double pesoPromedio;

  ///Atributos necesarios por default
  final bool seguir; //true

//  Si está en "true" el destino es venta, sino es recría.
  final bool vender;
  final bool cpcAutomatico;//false
  final double cpc;
  final double incremento; //0
  final double decremento; //0
  final double gdpv;
  final double materiaSeca;
  final String idDescarga;
  final DateTime primerDescarga;
  final DateTime ultimaDescarga;
  final DateTime ultimaFechaPesada;
  final double ultimaPesada;
  final DateTime ultimaLectura;
  final double remanente;
  final double descargado; //0
  final bool subtropa;
  final String tropaOrigen;
  final List<dynamic> subtropasList;


  Tropa({this.uuid, this.nombre, this.categoriaUid, this.corralUid, this.activo,
      this.cerrado, this.pendiente, this.potreroUid, this.propietario,
      this.dieta, this.caravana, this.cabezas, this.fechaAlta, this.fechaInicio,
      this.fechaUltimoEncierre, this.metaKilos, this.pesoInicio,
      this.pesoPromedio, this.seguir, this.vender, this.cpcAutomatico, this.cpc,
      this.incremento, this.decremento, this.gdpv, this.materiaSeca,
      this.idDescarga, this.primerDescarga, this.ultimaDescarga,
      this.ultimaFechaPesada, this.ultimaPesada, this.ultimaLectura,
      this.remanente, this.descargado, this.subtropa, this.tropaOrigen,
      this.subtropasList});

  Tropa copyWith(
      {String uuid,
      String nombre,
      String categoriaUid,
      String corralUid,
      bool activo,
      bool cerrado,
      bool pendiente,
      String potreroUid,
      String propietario,
      String dieta,
        bool caravana,
      int cabezas,
      DateTime fechaAlta,
      DateTime fechaInicio,
        DateTime fechaUltimoEncierre,
      double metaKilos,
      double pesoInicio,
      double pesoPromedio,
      bool seguir,
      bool vender,
      bool cpcAutomatico,
        double cpc,
      double incremento,
      double decremento,
      double gdpv,
      double materiaSeca,
      bool subtropa,
        String tropaOrigen,
      List<dynamic> subtropasList,
        double descargado,
        String idDescarga,
        DateTime primerDescarga,
        double remanente,
        DateTime ultimaDescarga,
        DateTime ultimaFechaPesada,
        DateTime ultimaLectura,
        double ultimaPesada,
      }) {
    return Tropa(
        uuid: uuid ?? this.uuid,
        nombre: nombre ?? this.nombre,
        categoriaUid: categoriaUid ?? this.categoriaUid,
        corralUid: corralUid ?? this.corralUid,
        activo: activo ?? this.activo,
        cerrado: cerrado ?? this.cerrado,
        pendiente: pendiente ?? this.pendiente,
        potreroUid: potreroUid ?? this.potreroUid,
        propietario: propietario ?? this.propietario,
        dieta: dieta ?? this.dieta,
        caravana:  caravana ?? this.caravana,
        cabezas: cabezas ?? this.cabezas,
        fechaAlta: fechaAlta ?? this.fechaAlta,
        fechaInicio: fechaInicio ?? this.fechaInicio,
        fechaUltimoEncierre: fechaUltimoEncierre ?? this.fechaUltimoEncierre,
        metaKilos: metaKilos ?? this.metaKilos,
        pesoInicio: pesoInicio ?? this.pesoInicio,
        pesoPromedio: pesoPromedio ?? this.pesoPromedio,
        seguir: seguir ?? this.seguir,
        vender: vender ?? this.vender,
        cpcAutomatico: cpcAutomatico ?? this.cpcAutomatico,
        cpc: cpc ?? this.cpc,
        incremento: incremento ?? this.incremento,
        decremento: decremento ?? this.decremento,
        gdpv: gdpv ?? this.gdpv,
        materiaSeca: materiaSeca ?? this.materiaSeca,
        subtropa: subtropa ?? this.subtropa,
        tropaOrigen: tropaOrigen ?? this.tropaOrigen,
        subtropasList: subtropasList ?? this.subtropasList,
        descargado: descargado ?? this.descargado,
        idDescarga: idDescarga ?? this.idDescarga,
        primerDescarga: primerDescarga ?? this.primerDescarga,
        remanente: remanente ?? this.remanente,
        ultimaDescarga: ultimaDescarga ?? this.ultimaDescarga,
        ultimaFechaPesada: ultimaFechaPesada ?? this.ultimaFechaPesada,
        ultimaLectura: ultimaLectura ?? this.ultimaLectura,
        ultimaPesada: ultimaPesada ?? this.ultimaPesada
    );
  }


  @override
  String toString() {
    return 'Tropa{uuid: $uuid, nombre: $nombre, categoriaUid: $categoriaUid, corralUid: $corralUid, activo: $activo, cerrado: $cerrado, pendiente: $pendiente, potreroUid: $potreroUid, propietario: $propietario, dieta: $dieta, caravana: $caravana, cabezas: $cabezas, fechaAlta: $fechaAlta, fechaInicio: $fechaInicio, fechaUltimoEncierre: $fechaUltimoEncierre, metaKilos: $metaKilos, pesoInicio: $pesoInicio, pesoPromedio: $pesoPromedio, seguir: $seguir, vender: $vender, cpcAutomatico: $cpcAutomatico, cpc: $cpc, incremento: $incremento, decremento: $decremento, gdpv: $gdpv, materiaSeca: $materiaSeca, idDescarga: $idDescarga, primerDescarga: $primerDescarga, ultimaDescarga: $ultimaDescarga, ultimaFechaPesada: $ultimaFechaPesada, ultimaPesada: $ultimaPesada, ultimaLectura: $ultimaLectura, remanente: $remanente, descargado: $descargado, subtropa: $subtropa, tropaOrigen: $tropaOrigen, subtropasList: $subtropasList}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Tropa &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              nombre == other.nombre &&
              categoriaUid == other.categoriaUid &&
              corralUid == other.corralUid &&
              activo == other.activo &&
              cerrado == other.cerrado &&
              pendiente == other.pendiente &&
              potreroUid == other.potreroUid &&
              propietario == other.propietario &&
              dieta == other.dieta &&
              caravana == other.caravana &&
              cabezas == other.cabezas &&
              fechaAlta == other.fechaAlta &&
              fechaInicio == other.fechaInicio &&
              fechaUltimoEncierre == other.fechaUltimoEncierre &&
              metaKilos == other.metaKilos &&
              pesoInicio == other.pesoInicio &&
              pesoPromedio == other.pesoPromedio &&
              seguir == other.seguir &&
              vender == other.vender &&
              cpcAutomatico == other.cpcAutomatico &&
              cpc == other.cpc &&
              incremento == other.incremento &&
              decremento == other.decremento &&
              gdpv == other.gdpv &&
              materiaSeca == other.materiaSeca &&
              idDescarga == other.idDescarga &&
              primerDescarga == other.primerDescarga &&
              ultimaDescarga == other.ultimaDescarga &&
              ultimaFechaPesada == other.ultimaFechaPesada &&
              ultimaPesada == other.ultimaPesada &&
              ultimaLectura == other.ultimaLectura &&
              remanente == other.remanente &&
              descargado == other.descargado &&
              subtropa == other.subtropa &&
              tropaOrigen == other.tropaOrigen &&
              subtropasList == other.subtropasList;

  @override
  int get hashCode =>
      uuid.hashCode ^
      nombre.hashCode ^
      categoriaUid.hashCode ^
      corralUid.hashCode ^
      activo.hashCode ^
      cerrado.hashCode ^
      pendiente.hashCode ^
      potreroUid.hashCode ^
      propietario.hashCode ^
      dieta.hashCode ^
      caravana.hashCode ^
      cabezas.hashCode ^
      fechaAlta.hashCode ^
      fechaInicio.hashCode ^
      fechaUltimoEncierre.hashCode ^
      metaKilos.hashCode ^
      pesoInicio.hashCode ^
      pesoPromedio.hashCode ^
      seguir.hashCode ^
      vender.hashCode ^
      cpcAutomatico.hashCode ^
      cpc.hashCode ^
      incremento.hashCode ^
      decremento.hashCode ^
      gdpv.hashCode ^
      materiaSeca.hashCode ^
      idDescarga.hashCode ^
      primerDescarga.hashCode ^
      ultimaDescarga.hashCode ^
      ultimaFechaPesada.hashCode ^
      ultimaPesada.hashCode ^
      ultimaLectura.hashCode ^
      remanente.hashCode ^
      descargado.hashCode ^
      subtropa.hashCode ^
      tropaOrigen.hashCode ^
      subtropasList.hashCode;

  TropaEntity toEntity() {
    return TropaEntity(uuid, nombre, categoriaUid, corralUid,
        activo, cerrado, pendiente, potreroUid,
        propietario, dieta, caravana,cabezas, fechaAlta,
        fechaInicio, metaKilos, pesoInicio, pesoPromedio,
        seguir, vender, cpcAutomatico, cpc,idDescarga,fechaUltimoEncierre,
        primerDescarga, ultimaDescarga, ultimaFechaPesada,
        ultimaPesada, ultimaLectura, remanente, incremento,
        descargado, decremento, gdpv, materiaSeca,
        subtropa, tropaOrigen, subtropasList);
  }

  static Tropa fromEntity(TropaEntity entity) {
    return Tropa(
        uuid: entity.uuid,
        nombre: entity.nombre,
        categoriaUid: entity.categoriaUid,
        corralUid: entity.corralUid,
        activo: entity.activo,
        cerrado: entity.cerrado,
        pendiente: entity.pendiente,
        potreroUid: entity.potreroUid,
        propietario: entity.propietario,
        dieta: entity.dieta,
        caravana: entity.caravana,
        cabezas: entity.cabezas,
        fechaAlta: entity.fechaAlta,
        fechaInicio: entity.fechaInicio,
        fechaUltimoEncierre: entity.fechaUltimoEncierre,
        metaKilos: entity.metaKilos,
        pesoInicio: entity.pesoInicio,
        pesoPromedio: entity.pesoPromedio,
        seguir: entity.seguir,
        vender: entity.vender,
        cpcAutomatico: entity.cpcAutomatico,
        cpc: entity.cpc,
        incremento: entity.incremento,
        decremento: entity.decremento,
        gdpv: entity.gdpv,
        materiaSeca: entity.materiaSeca,
        subtropa: entity.subtropa,
        tropaOrigen: entity.tropaOrigen,
        subtropasList: entity.subtropasList,
        ultimaPesada: entity.ultimaPesada,
        ultimaLectura: entity.ultimaLectura,
        ultimaFechaPesada: entity.ultimaFechaPesada,
        ultimaDescarga: entity.ultimaDescarga,
        remanente: entity.remanente,
        primerDescarga: entity.primerDescarga,
        idDescarga: entity.idDescarga,
        descargado: entity.descargado
    );
  }
}

==> 1.1.1.tar.gz: lib/src/models/tropa.dart <==
import 'package:firebase_repository/src/entities/entities.dart';
import 'package:meta/meta.dart';

@immutable
class Tropa {
  ///Atributos obligatorios:
  final String uuid;
  final String nombre;
  final String categoriaUid;
  final String corralUid;
  final bool activo;
  final bool cerrado;
  final bool pendiente;
  final String potreroUid;
  final String propietario;
  final String dieta;
  final bool caravana;

  ///Atributos autogenerados
  final int cabezas;
  final DateTime fechaAlta;
  final DateTime fechaInicio;
  final double metaKilos;
  final double pesoInicio;
  final double pesoPromedio;

  ///Atributos necesarios por default
  final bool seguir; //true

//  Si está en "true" el destino es venta, sino es recría.
  final bool vender;
  final bool cpcAutomatico;//false
  final double cpc;
  final double incremento; //0
  final double decremento; //0
  final double gdpv;
  final double materiaSeca;
  final String idDescarga;
  final DateTime primerDescarga;
  final DateTime ultimaDescarga;
  final DateTime ultimaFechaPesada;
  final double ultimaPesada;
  final DateTime ultimaLectura;
  final DateTime ultimaFechaCalculada;
  final double remanente;
  final double descargado; //0
  final bool subtropa;
  final String tropaOrigen;
  final List<dynamic> subtropasList;
  final double ultimoPrecio;


  Tropa({this.uuid, this.nombre, this.categoriaUid, this.corralUid, this.activo,
      this.cerrado, this.pendiente, this.potreroUid, this.propietario,
      this.dieta, this.caravana,this.cabezas, this.fechaAlta, this.fechaInicio, this.metaKilos,
      this.pesoInicio, this.pesoPromedio, this.seguir, this.vender,
      this.cpcAutomatico, this.cpc, this.incremento, this.decremento, this.gdpv,
      this.materiaSeca, this.idDescarga, this.primerDescarga,
      this.ultimaDescarga, this.ultimaFechaPesada, this.ultimaPesada,
      this.ultimaLectura, this.ultimaFechaCalculada,this.remanente, this.descargado, this.subtropa,
      this.tropaOrigen, this.subtropasList, this.ultimoPrecio});

  Tropa copyWith(
      {String uuid,
      String nombre,
      String categoriaUid,
      String corralUid,
      bool activo,
      bool cerrado,
      bool pendiente,
      String potreroUid,
      String propietario,
      String dieta,
        bool caravana,
      int cabezas,
      DateTime fechaAlta,
      DateTime fechaInicio,
      double metaKilos,
      double pesoInicio,
      double pesoPromedio,
      bool seguir,
      bool vender,
      bool cpcAutomatico,
        double cpc,
      double incremento,
      double decremento,
      double gdpv,
      double materiaSeca,
      bool subtropa,
        String tropaOrigen,
      List<dynamic> subtropasList,
        double descargado,
        String idDescarga,
        DateTime primerDescarga,
        double remanente,
        DateTime ultimaDescarga,
        DateTime ultimaFechaPesada,
        DateTime ultimaLectura,
        DateTime ultimaFechaCalculada,
        double ultimaPesada,
        double ultimoPrecio
      }) {
    return Tropa(
        uuid: uuid ?? this.uuid,
        nombre: nombre ?? this.nombre,
        categoriaUid: categoriaUid ?? this.categoriaUid,
        corralUid: corralUid ?? this.corralUid,
        activo: activo ?? this.activo,
        cerrado: cerrado ?? this.cerrado,
        pendiente: pendiente ?? this.pendiente,
        descargado: descargado ?? this.descargado,
        potreroUid: potreroUid ?? this.potreroUid,
        propietario: propietario ?? this.propietario,
        dieta: dieta ?? this.dieta,
        caravana:  caravana ?? this.caravana,
        cabezas: cabezas ?? this.cabezas,
        fechaAlta: fechaAlta ?? this.fechaAlta,
        fechaInicio: fechaInicio ?? this.fechaInicio,
        metaKilos: metaKilos ?? this.metaKilos,
        pesoInicio: pesoInicio ?? this.pesoInicio,
        pesoPromedio: pesoPromedio ?? this.pesoPromedio,
        seguir: seguir ?? this.seguir,
        vender: vender ?? this.vender,
        cpcAutomatico: cpcAutomatico ?? this.cpcAutomatico,
        cpc: cpc ?? this.cpc,
        incremento: incremento ?? this.incremento,
        decremento: decremento ?? this.decremento,
        gdpv: gdpv ?? this.gdpv,
        materiaSeca: materiaSeca ?? this.materiaSeca,
        subtropa: subtropa ?? this.subtropa,
        tropaOrigen: tropaOrigen ?? this.tropaOrigen,
        subtropasList: subtropasList ?? this.subtropasList,
        idDescarga: idDescarga ?? this.idDescarga,
        primerDescarga: primerDescarga ?? this.primerDescarga,
        remanente: remanente ?? this.remanente,
        ultimaDescarga: ultimaDescarga ?? this.ultimaDescarga,
        ultimaFechaPesada: ultimaFechaPesada ?? this.ultimaFechaPesada,
        ultimaLectura: ultimaLectura ?? this.ultimaLectura,
        ultimaFechaCalculada: ultimaFechaCalculada ?? this.ultimaFechaCalculada,
        ultimaPesada: ultimaPesada ?? this.ultimaPesada,
        ultimoPrecio: ultimoPrecio ?? this.ultimoPrecio
    );
  }


  @override
  String toString() {
    return 'Tropa{uuid: $uuid, nombre: $nombre, categoriaUid: $categoriaUid, corralUid: $corralUid, activo: $activo, cerrado: $cerrado, pendiente: $pendiente, potreroUid: $potreroUid, propietario: $propietario, dieta: $dieta, caravana: $caravana, cabezas: $cabezas, fechaAlta: $fechaAlta, fechaInicio: $fechaInicio, metaKilos: $metaKilos, pesoInicio: $pesoInicio, pesoPromedio: $pesoPromedio, seguir: $seguir, vender: $vender, cpcAutomatico: $cpcAutomatico, cpc: $cpc, incremento: $incremento, decremento: $decremento, gdpv: $gdpv, materiaSeca: $materiaSeca, idDescarga: $idDescarga, primerDescarga: $primerDescarga, ultimaDescarga: $ultimaDescarga, ultimaFechaPesada: $ultimaFechaPesada, ultimaPesada: $ultimaPesada, ultimaLectura: $ultimaLectura, ultimaFechaCalculada: $ultimaFechaCalculada, remanente: $remanente, descargado: $descargado, subtropa: $subtropa, tropaOrigen: $tropaOrigen, subtropasList: $subtropasList, ultimoPrecio: $ultimoPrecio}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Tropa &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              nombre == other.nombre &&
              categoriaUid == other.categoriaUid &&
              corralUid == other.corralUid &&
              activo == other.activo &&
              cerrado == other.cerrado &&
              pendiente == other.pendiente &&
              potreroUid == other.potreroUid &&
              propietario == other.propietario &&
              dieta == other.dieta &&
              caravana == other.caravana &&
              cabezas == other.cabezas &&
              fechaAlta == other.fechaAlta &&
              fechaInicio == other.fechaInicio &&
              metaKilos == other.metaKilos &&
              pesoInicio == other.pesoInicio &&
              pesoPromedio == other.pesoPromedio &&
              seguir == other.seguir &&
              vender == other.vender &&
              cpcAutomatico == other.cpcAutomatico &&
              cpc == other.cpc &&
              incremento == other.incremento &&
              decremento == other.decremento &&
              gdpv == other.gdpv &&
              materiaSeca == other.materiaSeca &&
              idDescarga == other.idDescarga &&
              primerDescarga == other.primerDescarga &&
              ultimaDescarga == other.ultimaDescarga &&
              ultimaFechaPesada == other.ultimaFechaPesada &&
              ultimaPesada == other.ultimaPesada &&
              ultimaLectura == other.ultimaLectura &&
              ultimaFechaCalculada == other.ultimaFechaCalculada &&
              remanente == other.remanente &&
              descargado == other.descargado &&
              subtropa == other.subtropa &&
              tropaOrigen == other.tropaOrigen &&
              subtropasList == other.subtropasList &&
              ultimoPrecio == other.ultimoPrecio;

  @override
  int get hashCode =>
      uuid.hashCode ^
      nombre.hashCode ^
      categoriaUid.hashCode ^
      corralUid.hashCode ^
      activo.hashCode ^
      cerrado.hashCode ^
      pendiente.hashCode ^
      potreroUid.hashCode ^
      propietario.hashCode ^
      dieta.hashCode ^
      caravana.hashCode ^
      cabezas.hashCode ^
      fechaAlta.hashCode ^
      fechaInicio.hashCode ^
      metaKilos.hashCode ^
      pesoInicio.hashCode ^
      pesoPromedio.hashCode ^
      seguir.hashCode ^
      vender.hashCode ^
      cpcAutomatico.hashCode ^
      cpc.hashCode ^
      incremento.hashCode ^
      decremento.hashCode ^
      gdpv.hashCode ^
      materiaSeca.hashCode ^
      idDescarga.hashCode ^
      primerDescarga.hashCode ^
      ultimaDescarga.hashCode ^
      ultimaFechaPesada.hashCode ^
      ultimaPesada.hashCode ^
      ultimaLectura.hashCode ^
      ultimaFechaCalculada.hashCode ^
      remanente.hashCode ^
      descargado.hashCode ^
      subtropa.hashCode ^
      tropaOrigen.hashCode ^
      subtropasList.hashCode ^
      ultimoPrecio.hashCode;

  TropaEntity toEntity() {
    return TropaEntity(uuid, nombre, categoriaUid, corralUid,
        activo, cerrado, pendiente, potreroUid,
        propietario, dieta, caravana,cabezas, fechaAlta,
        fechaInicio, metaKilos, pesoInicio, pesoPromedio,
        seguir, vender, cpcAutomatico, cpc,idDescarga,
        primerDescarga, ultimaDescarga, ultimaFechaPesada,
        ultimaPesada, ultimaLectura, ultimaFechaCalculada,remanente, incremento,
        descargado, decremento, gdpv, materiaSeca,
        subtropa, tropaOrigen, subtropasList, ultimoPrecio);
  }

  static Tropa fromEntity(TropaEntity entity) {
    return Tropa(
        uuid: entity.uuid,
        nombre: entity.nombre,
        categoriaUid: entity.categoriaUid,
        corralUid: entity.corralUid,
        activo: entity.activo,
        cerrado: entity.cerrado,
        pendiente: entity.pendiente,
        potreroUid: entity.potreroUid,
        propietario: entity.propietario,
        dieta: entity.dieta,
        caravana: entity.caravana,
        cabezas: entity.cabezas,
        fechaAlta: entity.fechaAlta,
        fechaInicio: entity.fechaInicio,
        metaKilos: entity.metaKilos,
        pesoInicio: entity.pesoInicio,
        pesoPromedio: entity.pesoPromedio,
        seguir: entity.seguir,
        vender: entity.vender,
        cpcAutomatico: entity.cpcAutomatico,
        cpc: entity.cpc,
        incremento: entity.incremento,
        decremento: entity.decremento,
        gdpv: entity.gdpv,
        materiaSeca: entity.materiaSeca,
        subtropa: entity.subtropa,
        tropaOrigen: entity.tropaOrigen,
        subtropasList: entity.subtropasList,
        ultimaPesada: entity.ultimaPesada,
        ultimaLectura: entity.ultimaLectura,
        ultimaFechaPesada: entity.ultimaFechaPesada,
        ultimaDescarga: entity.ultimaDescarga,
        ultimaFechaCalculada: entity.ultimaFechaCalculada,
        remanente: entity.remanente,
        primerDescarga: entity.primerDescarga,
        idDescarga: entity.idDescarga,
        descargado: entity.descargado,
      ultimoPrecio: entity.ultimoPrecio
    );
  }
}
